@@ -304,7 +304,7 @@ def parse_tpu_master(tpu):
   return '{}:{}'.format(tpu.get('ipAddress',''), tpu.get('port', 8470))
 
 def parse_tpu_range(tpu):
-  return tpu['cidrBlock']
+  return tpu.get('cidrBlock', None)
 
 def parse_tpu_version(tpu):
   return tpu['tensorflowVersion']
@@ -350,6 +350,7 @@ def format(tpu, spec=None, formatter=NamespaceFormatter):
     args = {}
     args.update(tpu)
     args.update(format_widths())
+  args = {k: v or '' for k, v in args.items()}
   fmt = formatter(args)
   if spec is None:
     spec = get_default_format_spec(thin=len(format_widths()) == 0)
